@@ -15,13 +15,13 @@
 
 #include "application.h"
 #include "version.h"
-#include "commit.h"
 
 #include <QMutex>
 #include <QWaitCondition>
 #include <QCommandLineParser>
 
 #include <KAboutData>
+#include <KCrash>
 #include <Kdelibs4ConfigMigrator>
 #include <KDBusAddons/KDBusService>
 
@@ -49,7 +49,7 @@ int main(int argc, char* argv[])
         KONVI_VERSION,
         i18n("A user-friendly IRC client"),
         KAboutLicense::GPL,
-        i18n("(C) 2002-2014 by the Konversation team"),
+        i18n("(C) 2002-2016 by the Konversation team"),
         i18n("Konversation is a client for the Internet Relay Chat (IRC) protocol.\n\n"
         "Meet friends on the net, make new acquaintances and lose yourself in talk about your favorite subject."),
         QStringLiteral("http://konversation.kde.org/"));
@@ -96,11 +96,14 @@ int main(int argc, char* argv[])
 
     KAboutData::setApplicationData(aboutData);
 
+    KCrash::initialize();
+
     app.setApplicationName(aboutData.componentName());
     app.setOrganizationDomain(aboutData.organizationDomain());
     app.setApplicationVersion(aboutData.version());
     app.setApplicationDisplayName(aboutData.displayName());
     app.setAttribute(Qt::AA_UseHighDpiPixmaps, true);
+    app.setWindowIcon(QIcon::fromTheme(QLatin1String("konversation")));
 
     QCommandLineParser cmdLineParser;
     cmdLineParser.addHelpOption();
